@@ -5,11 +5,12 @@ from pathlib import Path
 from typing import Optional, Tuple
 
 from pydantic import SecretStr
+from textual import work
 from textual.app import App, ComposeResult
 from textual.binding import Binding
 from textual.containers import Horizontal, Vertical
 from textual.screen import Screen
-from textual.widgets import Button, Footer, Static
+from textual.widgets import Button, Footer, Static, Link
 
 from ..widgets import (
     ValidatedTextInput,
@@ -17,12 +18,14 @@ from ..widgets import (
     LoadableList,
     SystemInfoWidget,
 )
-from ..widgets.config_dialogs import MCPConfigWriteDialog, AgentRulesWriteDialog
+from ..widgets.config_dialogs import MCPConfigWriteDialog, AgentRulesWriteDialog, AgentSelectionDialog
+from ..widgets.info_help_dialog import InfoHelpDialog
 from ...models.integration_status import IntegrationStatus
 from ...services.config_service import ConfigurationService, ConfigurationError
 from ...services.integration_status_service import IntegrationStatusService
 from ...services.mcp_config_service import MCPConfigService, MCPConfigStatus
-from ...services.agent_rules_service import AgentRulesService, AgentRulesStatus
+from ...services.agent_rules_service import AgentRulesService
+from ...agent_setups.base import AgentRulesStatus
 from ...services.nautex_api_service import NautexAPIService
 from ...models.config import NautexConfig
 from ...utils import path2display
@@ -53,8 +56,10 @@ class SetupScreen(Screen):
         Binding("escape", "quit", "Quit"),
         Binding("tab", "next_input", "Next Field"),
         Binding("enter", "next_input", "Next Field"),
+        Binding("ctrl+y", "show_agent_selection_dialog", "Select Agent Type"),
         Binding("ctrl+t", "show_mcp_dialog", "MCP Config"),
         Binding("ctrl+r", "show_agent_rules_dialog", "Agent Rules"),
+        Binding("f1", "show_info_help", "Info & Help"),
     ]
 
     CSS = """
@@ -147,7 +152,8 @@ class SetupScreen(Screen):
         self.setup_data = {}
 
         # Create API token link (using Static with markup instead of Link)
-        api_token_link = Static("[link=https://app.nautex.ai/settings/nautex-api]Get one from: app.nautex.ai/settings/nautex-api[/link]", markup=True)
+        api_token_link = Link("Get API token from: app.nautex.ai/settings/nautex-api",
+                              url="(https://app.nautex.ai/settings/nautex-api)", tooltip="Get API Key")
 
         # Widget references
         self.integration_status_widget = IntegrationStatusWidget()
@@ -211,7 +217,7 @@ class SetupScreen(Screen):
             return False, "API token must be at least 8 characters"
 
         try:
-            acc_info = await self.api_service.get_account_info(token_override=value, timeout=1.0)
+            acc_info = await self.api_service.get_account_info(token_override=value, raise_exception=True, timeout=5.0)
             self.system_info_widget.update_system_info(
                 email=acc_info.profile_email,
             )
@@ -328,6 +334,10 @@ class SetupScreen(Screen):
         self.app.log(f"Implementation plan selection changed: {selected_item.name if hasattr(selected_item, 'name') else selected_item}")
 
         self.config_service.config.plan_id = selected_item.id
+
+        # touching the plan for pushing notification for an onboarding process
+        plan = await self.api_service.get_implementation_plan(self.config_service.config.project_id,
+                                                              self.config_service.config.plan_id)
         self.config_service.save_configuration()
 
 
@@ -415,34 +425,46 @@ class SetupScreen(Screen):
         # Focus the next widget
         self.focusable_widgets[self.current_focus_index].focus()
 
-    async def action_show_mcp_dialog(self) -> None:
+    async def show_dialog(self, dialog):
 
-        dialog = MCPConfigWriteDialog(mcp_service=self.mcp_config_service)
-        result = await self.app.push_screen(dialog)
+        async def sd():
+            result = await self.app.push_screen_wait(dialog)
 
-        if result:
-            # Refresh the system info to show updated status
             await self._update_system_info()
             await self.update_integration_status()
 
+        self.run_worker(sd())
+
+    async def action_show_mcp_dialog(self) -> None:
+        dialog = MCPConfigWriteDialog(mcp_service=self.mcp_config_service)
+        await self.show_dialog(dialog)
+
 
     async def action_show_agent_rules_dialog(self) -> None:
-
         dialog = AgentRulesWriteDialog(rules_service=self.agent_rules_service)
-        result = await self.app.push_screen(dialog)
+        await self.show_dialog(dialog)
+
+    async def action_show_agent_selection_dialog(self) -> None:
+        dialog = AgentSelectionDialog(
+            config_service=self.config_service,
+            integration_status_service=self.integration_status_service
+        )
+
+        await self.show_dialog(dialog)
+
+    async def action_show_info_help(self) -> None:
+        """Show the info and help dialog."""
+        dialog = InfoHelpDialog()
+        await self.show_dialog(dialog)
 
-        if result:
-            # Refresh the system info to show updated status
-            await self._update_system_info()
-            await self.update_integration_status()
 
     async def _update_system_info(self) -> None:
         """Update the system info widget with current data."""
         # Get agent_type from config
         agent_type = self.config_service.config.agent_type
 
-        mcp_config_status, _ = self.mcp_config_service.check_mcp_configuration()
-        agent_rules_status, _ = self.agent_rules_service.check_rules_file()
+        mcp_config_status, _ = await self.mcp_config_service.check_mcp_configuration()
+        agent_rules_status, _ = self.agent_rules_service.validate_rules()
 
         self.system_info_widget.update_system_info(
             host=self.config_service.config.api_host,
